@@ -42,6 +42,10 @@
 #ifdef USE_SYSTEMD
 #include <systemd/sd-daemon.h>
 #else
+#define SD_LISTEN_FDS_START 3
+#define sd_is_socket(fd, f, t, l) (0)
+#define sd_listen_fds(ue) (0)
+#define sd_listen_fds_with_names(ue, n) (0)
 #define sd_notify(ue, s)
 #define sd_notifyf(ue, f, ...)
 #endif
@@ -120,6 +124,12 @@ extern int cf_sbuf_len;
 #include "hba.h"
 #include "pam.h"
 
+#ifndef WIN32
+#define DEFAULT_UNIX_SOCKET_DIR "/tmp"
+#else
+#define DEFAULT_UNIX_SOCKET_DIR ""
+#endif
+
 /* to avoid allocations will use static buffers */
 #define MAX_DBNAME	64
 #define MAX_USERNAME	64
@@ -302,6 +312,9 @@ struct PgUser {
 	struct AANode tree_node;	/* used to attach user to tree */
 	char name[MAX_USERNAME];
 	char passwd[MAX_PASSWORD];
+	uint8_t scram_ClientKey[32];
+	uint8_t scram_ServerKey[32];
+	bool has_scram_keys;		/* true if the above two are valid */
 	int pool_mode;
 	int max_user_connections;	/* how much server connections are allowed */
 	int connection_count;	/* how much connections are used by user now */
@@ -410,9 +423,11 @@ struct PgSocket {
 		char *server_first_message;
 		uint8_t	*SaltedPassword;
 		char cbind_flag;
+		bool adhoc;	/* SCRAM data made up from plain-text password */
 		int iterations;
 		char *salt;	/* base64-encoded */
-		uint8_t StoredKey[32];	/* SHA256_DIGEST_LENGTH */
+		uint8_t ClientKey[32];	/* SHA256_DIGEST_LENGTH */
+		uint8_t StoredKey[32];
 		uint8_t ServerKey[32];
 	} scram_state;
 
