@@ -220,8 +220,8 @@ CF_ABS("listen_addr", CF_STR, cf_listen_addr, CF_NO_RELOAD, ""),
 CF_ABS("listen_port", CF_INT, cf_listen_port, CF_NO_RELOAD, "6432"),
 CF_ABS("so_reuseport", CF_INT, cf_so_reuseport, CF_NO_RELOAD, "0"),
 CF_ABS("listen_backlog", CF_INT, cf_listen_backlog, CF_NO_RELOAD, "128"),
+CF_ABS("unix_socket_dir", CF_STR, cf_unix_socket_dir, CF_NO_RELOAD, DEFAULT_UNIX_SOCKET_DIR),
 #ifndef WIN32
-CF_ABS("unix_socket_dir", CF_STR, cf_unix_socket_dir, CF_NO_RELOAD, "/tmp"),
 CF_ABS("unix_socket_mode", CF_INT, cf_unix_socket_mode, CF_NO_RELOAD, "0777"),
 CF_ABS("unix_socket_group", CF_STR, cf_unix_socket_group, CF_NO_RELOAD, ""),
 #endif
@@ -707,7 +707,7 @@ static bool check_old_process_unix(void)
 	int domain = AF_UNIX;
 	int res, fd;
 
-	if (!cf_unix_socket_dir || !*cf_unix_socket_dir)
+	if (!cf_unix_socket_dir || !*cf_unix_socket_dir || sd_listen_fds(0) > 0)
 		return false;
 
 	memset(&sa_un, 0, len);
@@ -757,6 +757,9 @@ static void takeover_part1(void)
 	if (!cf_unix_socket_dir || !*cf_unix_socket_dir)
 		die("cannot reboot if unix dir not configured");
 
+	if (sd_listen_fds(0) > 0)
+		die("cannot reboot under service manager");
+
 	takeover_init();
 	while (cf_reboot)
 		main_loop_once();
@@ -782,6 +785,7 @@ static void xfree(char **ptr_p)
 	}
 }
 
+_UNUSED
 static void cleanup(void)
 {
 	adns_free_context(adns);
@@ -972,7 +976,9 @@ int main(int argc, char *argv[])
 		main_loop_once();
 
 	/* not useful for production loads */
-	if (0) cleanup();
+#ifdef CASSERT
+	cleanup();
+#endif
 
 	return 0;
 }
