@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
 # Notes:
 # - uses iptables and -F with some tests, probably not very friendly to your firewall
@@ -135,7 +135,9 @@ psql -X -p $PG_PORT -d p0 -c "select * from pg_user" | grep pswcheck > /dev/null
 		psql -X -o /dev/null -p $PG_PORT -c "set password_encryption = 'md5'; create user muser2 password 'wrong';" p0 || exit 1
 		psql -X -o /dev/null -p $PG_PORT -c "set password_encryption = 'md5'; create user puser1 password 'foo';" p0 || exit 1
 		psql -X -o /dev/null -p $PG_PORT -c "set password_encryption = 'md5'; create user puser2 password 'wrong';" p0 || exit 1
-		psql -X -o /dev/null -p $PG_PORT -c "set password_encryption = 'scram-sha-256'; create user scramuser1 password 'foo';" p0 || exit 1
+		# match SCRAM secret in userlist.txt
+		psql -X -o /dev/null -p $PG_PORT -c "set password_encryption = 'scram-sha-256'; create user scramuser1 password '"'SCRAM-SHA-256$4096:D76gvGUVj9Z4DNiGoabOBg==$RukL0Xo3Ql/2F9FsD7mcQ3GATG2fD3PA71qY1JagGDs=:BhKUwyyivFm7Tq2jDJVXSVRbRDgTWyBilZKgg6DDuYU='"';" p0 || exit 1
+		psql -X -o /dev/null -p $PG_PORT -c "set password_encryption = 'scram-sha-256'; create user scramuser3 password 'baz';" p0 || exit 1
 	else
 		psql -X -o /dev/null -p $PG_PORT -c "set password_encryption = on; create user muser1 password 'foo';" p0 || exit 1
 		psql -X -o /dev/null -p $PG_PORT -c "set password_encryption = on; create user muser2 password 'wrong';" p0 || exit 1
@@ -268,6 +270,23 @@ test_show_version() {
 	test x"$v1" = x"$v2"
 }
 
+# test all the show commands
+#
+# This test right now just runs all the commands without checking the
+# output, which would be difficult.  This at least ensures the
+# commands don't completely die.  The output can be manually eyeballed
+# in the test log file.
+test_show() {
+	for what in clients config databases fds help lists pools servers sockets active_sockets stats stats_totals stats_averages users totals mem dns_hosts dns_zones; do
+		    echo "=> show $what;"
+		    psql -X -h /tmp -U pgbouncer -d pgbouncer -c "show $what;" || return 1
+	done
+
+	psql -X -h /tmp -U pgbouncer -d pgbouncer -c "show bogus;" && return 1
+
+	return 0
+}
+
 # server_lifetime
 test_server_lifetime() {
 	admin "set server_lifetime=2"
@@ -870,25 +889,51 @@ test_scram_client() {
 	return 0
 }
 
-# test all the show commands
-#
-# This test right now just runs all the commands without checking the
-# output, which would be difficult.  This at least ensures the
-# commands don't completely die.  The output can be manually eyeballed
-# in the test log file.
-test_show() {
-	for what in clients config databases fds help lists pools servers sockets active_sockets stats stats_totals stats_averages users totals mem dns_hosts dns_zones; do
-		    echo "=> show $what;"
-		    psql -X -h /tmp -U pgbouncer -d pgbouncer -c "show $what;" || return 1
-	done
+# test SCRAM authentication from client to PgBouncer and on to server
+test_scram_both() {
+	$pg_supports_scram || return 77
 
-	psql -X -h /tmp -U pgbouncer -d pgbouncer -c "show bogus;" && return 1
+	admin "set auth_type='scram-sha-256'"
+
+	# plain-text password in userlist.txt
+	PGPASSWORD=baz psql -X -U scramuser3 -c "select 1" p61 || return 1
+
+	# SCRAM password in userlist.txt
+	PGPASSWORD=foo psql -X -U scramuser1 -c "select 1" p62 || return 1
 
 	return 0
 }
 
+# test that SCRAM authentication pass-through is preserved by online
+# restart
+#
+# Note: coproc requires bash >=4
+test_scram_takeover() {
+	$pg_supports_scram || return 77
+
+	admin "set auth_type='scram-sha-256'"
+	admin "set pool_mode=transaction"
+	admin "set server_lifetime=3"
+
+	{ coproc { PGPASSWORD=foo psql -X -U scramuser1 -f - -d p62; } >&3; } 3>&1
+
+	echo "select 1;" >&"${COPROC[1]}"
+	sleep 4  # wait for server_lifetime
+
+	$BOUNCER_EXE -d -R $BOUNCER_INI
+	sleep 1
+
+	echo "select 2;" >&"${COPROC[1]}"
+	echo "\q" >&"${COPROC[1]}"
+
+	wait $COPROC_PID
+
+	test $? -eq 0
+}
+
 testlist="
 test_show_version
+test_show
 test_server_login_retry
 test_auth_user
 test_client_idle_timeout
@@ -919,7 +964,8 @@ test_md5_server
 test_md5_client
 test_scram_server
 test_scram_client
-test_show
+test_scram_both
+test_scram_takeover
 "
 
 if [ $# -gt 0 ]; then
